@@ -249,6 +249,8 @@ gail_window_real_initialize (AtkObject *obj,
     obj->role = ATK_ROLE_COLOR_CHOOSER;
   else if (GTK_IS_FONT_SELECTION_DIALOG (widget))
     obj->role = ATK_ROLE_FONT_CHOOSER;
+  else if (GTK_IS_MESSAGE_DIALOG (widget))
+    obj->role = ATK_ROLE_ALERT;
   else if (GTK_IS_DIALOG (widget))
     obj->role = ATK_ROLE_DIALOG;
   else if (GTK_IS_WINDOW (widget))
